@@ -1,12 +1,14 @@
 # Setup fedmsg logging.
 # See the following for constraints on this format http://bit.ly/Xn1WDn
+bare_format = "[%(asctime)s][%(name)10s %(levelname)7s] %(message)s"
+
 config = dict(
     logging=dict(
         version=1,
         formatters=dict(
             bare={
                 "datefmt": "%Y-%m-%d %H:%M:%S",
-                "format": "[%(asctime)s][%(name)10s %(levelname)7s] %(message)s"
+                "format": bare_format
             },
         ),
         handlers=dict(
